# snackademics


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Snackademics is a playful blend of “snacks” and “academics” - it
suggests learning in a fun, bite-sized way, rather than heavy academic
study. Like having a light snack instead of a full formal meal, but for
learning!

The name implies that you can approach learning in a casual, snackable
way while still getting the benefits of academic understanding. It’s
meant to make learning feel less intimidating and more enjoyable.

## Developer Guide

If you are new to using `nbdev` here are some useful pointers to get you
started.

### Install snackademics in Development mode

``` sh
# make sure snackademics package is installed in development mode
$ pip install -e .

# make changes under nbs/ directory
# ...

# compile to have changes apply to snackademics
$ nbdev_prepare
```

## Usage

### Installation

Install latest from the GitHub
[repository](https://github.com/galopyz/snackademics):

``` sh
$ pip install git+https://github.com/galopyz/snackademics.git
```

or from [conda](https://anaconda.org/galopyz/snackademics)

``` sh
$ conda install -c galopyz snackademics
```

or from [pypi](https://pypi.org/project/snackademics/)

``` sh
$ pip install snackademics
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/galopyz/snackademics)’s
[pages](https://galopyz.github.io/snackademics/). Additionally you can
find package manager specific guidelines on
[conda](https://anaconda.org/galopyz/snackademics) and
[pypi](https://pypi.org/project/snackademics/) respectively.

## How to use

Coming soon..
